@@ -169,12 +169,12 @@ Get a static text-based response directly from a text-based AI model without usi
     
     return tools, tools_schema, master_available_tools, available_tools, tool_descriptions, prompts, prompts_schema, resources, templates
 
-def display_info(console, info, title=None):
+def display_info(console, info, title=None, border_style=config.color_info_border):
     """ Info panel with background """
     info_panel = Panel(
         Text(info, style="bold white on grey11", justify="center") if isinstance(info, str) else info,
         title=title,
-        border_style="bright_blue",
+        border_style=border_style,
         box=box.ROUNDED,
         style="on grey11" if isinstance(info, str) else "",
         #padding=(1 if isinstance(info, str) else 0, 1) # (0, 1) by default
@@ -234,8 +234,9 @@ async def main_async():
     async with client:
 
         console = Console(record=True)
-        console.clear()
-        console.print(get_banner(COMPUTEMATE_VERSION))
+        if not (args.default and args.exit):
+            console.clear()
+            console.print(get_banner(COMPUTEMATE_VERSION))
 
         tools, tools_schema, master_available_tools, available_tools, tool_descriptions, prompts, prompts_schema, resources, templates = await initialize_app(client)
         # format input suggestions
@@ -368,14 +369,6 @@ async def main_async():
                     os.chdir(cwd)
                     display_info(console, list_dir_content(cwd), title=cwd)
                 continue
-            elif re.search(r"\?\?(.*?)\?\? ", user_request+" "):
-                fileList = [os.path.abspath(i) for i in re.findall(r"\?\?(.*?)\?\? ", user_request+" ")]
-                new_user_request = re.sub(r"\?\?(.*?)\?\? ", "", user_request+" ").strip()
-                new_user_request = f'''# File List\n\n{fileList}\n\n# User Request\n\n{new_user_request}'''
-                if config.agent_mode is None and not user_request.startswith("@"):
-                    user_request = ("@computemate_ask_files " if len(config_mcp) > 1 else "@ask_files ") + "\n\n" + new_user_request
-                else:
-                    user_request = new_user_request
             if user_request == ".ideas":
                 # Generate ideas for `prompts to try`
                 ideas = ""
@@ -509,9 +502,17 @@ async def main_async():
                     console.print(get_banner(COMPUTEMATE_VERSION))
                     if messages:
                         for i in messages:
-                            if i.get("role", "") in ("user", "assistant"):
-                                console.rule()
-                                console.print(Markdown(f"# {i['role']}\n\n{i['content']}"))
+                            if i.get("role", "") == "user":
+                                if config.agent_mode:
+                                    border_style = config.color_agent_mode
+                                elif config.agent_mode is not None:
+                                    border_style = config.color_partner_mode
+                                else:
+                                    border_style = "none"
+                                display_info(console,Markdown(i['content'].strip()), border_style=border_style)
+                            elif i.get("role", "") == "assistant":
+                                console.print(Markdown(i['content'].strip()))
+                                console.print()
                     if os.path.isfile(load_path) or config.agent_mode is None:
                         # next user request
                         os.chdir(cwd)
@@ -818,6 +819,19 @@ Viist https://github.com/eliranwong/computemate
             # auto tool selection in chat mode
             if config.agent_mode is None and config.auto_tool_selection and not user_request.startswith("@"):
                 user_request = f"@ {user_request}"
+            elif re.search(r"\?\?(.*?)\?\? ", user_request+" "):
+                if found_tool := re.search("^(@[^ ]*? )", user_request):
+                    file_tool = found_tool.group(1)
+                    user_request = user_request[len(file_tool):]
+                else:
+                    file_tool = ""
+                fileList = [os.path.abspath(i) for i in re.findall(r"\?\?(.*?)\?\? ", user_request+" ")]
+                new_user_request = re.sub(r"\?\?(.*?)\?\? ", "", user_request+" ").strip()
+                new_user_request = f'''# File List\n\n{fileList}\n\n# User Request\n\n{new_user_request}'''
+                if config.agent_mode is None and not file_tool:
+                    user_request = ("@computemate_ask_files " if len(config_mcp) > 1 else "@ask_files ") + "\n\n" + new_user_request
+                else:
+                    user_request = f"{file_tool}\n{new_user_request}"
             
             if user_request.startswith("@ "):
                 user_request = user_request[2:].strip()
@@ -916,6 +930,11 @@ Viist https://github.com/eliranwong/computemate
                         if tool in ("computemate_execute_task", "execute_task"):
                             tool_instruction = "# Instruction\n\n"+tool_instruction+"\n\n# Supplementary Device Information\n\n"+getDeviceInfo()
                             tool_result = agentmake(tool_instruction, **{'tool': 'magic' if config.auto_code_correction else 'execute_task'}, **AGENTMAKE_CONFIG)[-1].get("content") if messages and "content" in messages[-1] else "Error!"
+                            #tool_result = agentmake(tool_instruction, **{'tool': 'execute_task'}, **AGENTMAKE_CONFIG)[-1].get("content") if messages and "content" in messages[-1] else "Error!"
+                        elif tool in ("online_search_finance", "search_finance"):
+                            tool_result = agentmake(tool_instruction, **{'tool': 'search/finance'}, **AGENTMAKE_CONFIG)[-1].get("content") if messages and "content" in messages[-1] else "Error!"
+                        elif tool in ("utilities_create_statistical_graph", "create_statistical_graph"):
+                            tool_result = agentmake(tool_instruction, **{'tool': 'create/statistical_graph'}, **AGENTMAKE_CONFIG)[-1].get("content") if messages and "content" in messages[-1] else "Error!"
                         elif tool in ("computemate_email_outlook", "email_outlook", "computemate_email_gmail", "email_gmail"):
                             tool_result = agentmake(tool_instruction, **{'tool': 'email/outlook' if 'outlook' in tool else 'email/gmail'}, **AGENTMAKE_CONFIG)[-1].get("content") if messages and "content" in messages[-1] else "Error!"
                         elif tool in ("computemate_calendar_outlook", "calendar_outlook", "computemate_calendar_google", "calendar_google"):
@@ -955,18 +974,29 @@ Viist https://github.com/eliranwong/computemate
 
             # user specify a single tool
             if specified_tool and not specified_tool == "@@" and not specified_prompt:
+                if config.agent_mode:
+                    border_style = config.color_agent_mode
+                elif config.agent_mode is not None:
+                    border_style = config.color_partner_mode
+                else:
+                    border_style = "none"
+                display_info(console,Markdown(messages[-1]['content']), border_style=border_style)
                 await process_tool(specified_tool, user_request)
-                console.print(Markdown(f"# User Request\n\n{messages[-2]['content']}\n\n# AI Response\n\n{messages[-1]['content']}"))
+                print()
+                console.print(Markdown(messages[-1]['content']))
                 console.print()
+                config.backup_required = True
                 continue
 
             # Chat mode
             if config.agent_mode is None and not specified_tool == "@@" and not specified_prompt:
+                display_info(console,Markdown(messages[-1]['content']), border_style="none")
                 async def run_chat_mode():
                     nonlocal messages, user_request
                     messages = agentmake(messages if messages else user_request, system="auto", **AGENTMAKE_CONFIG)
                 await thinking(run_chat_mode, "Processing your request ...")
-                console.print(Markdown(f"# User Request\n\n{messages[-2]['content']}\n\n# AI Response\n\n{messages[-1]['content']}"))
+                print()
+                console.print(Markdown(messages[-1]['content']))
                 # temporaily save after each step
                 backup_conversation(messages, "")
                 config.backup_required = True
